@@ -7,7 +7,7 @@ import (
 
 var oplogCmd = &cobra.Command{
 	Use:     "oplog",
-	Short:   "Show operation history",
+	Short:   "Commands for viewing and managing operation history",
 	Run:     func(cmd *cobra.Command, args []string) {},
 	GroupID: "operation history",
 }
@@ -16,6 +16,5 @@ func init() {
 	carapace.Gen(oplogCmd).Standalone()
 
 	oplogCmd.Flags().BoolP("help", "h", false, "Print help (see more with '--help')")
-	oplogCmd.Flags().String("since", "", "Start from this oplog SHA instead of the head")
 	rootCmd.AddCommand(oplogCmd)
 }
