@@ -16,8 +16,9 @@ func init() {
 	carapace.Gen(image_historyCmd).Standalone()
 
 	image_historyCmd.Flags().String("format", "", "Format output using a custom template:")
-	image_historyCmd.Flags().BoolP("human", "H", true, "Print sizes and dates in human readable format")
+	image_historyCmd.Flags().BoolP("human", "H", false, "Print sizes and dates in human readable format")
 	image_historyCmd.Flags().Bool("no-trunc", false, "Don't truncate output")
+	image_historyCmd.Flags().String("platform", "", "Show history for the given platform. Formatted as \"os[/arch[/variant]]\" (e.g., \"linux/amd64\")")
 	image_historyCmd.Flags().BoolP("quiet", "q", false, "Only show image IDs")
 	imageCmd.AddCommand(image_historyCmd)
 
