@@ -16,9 +16,10 @@ func init() {
 	carapace.Gen(image_pullCmd).Standalone()
 
 	image_pullCmd.Flags().BoolP("all-tags", "a", false, "Download all tagged images in the repository")
-	image_pullCmd.Flags().Bool("disable-content-trust", true, "Skip image verification")
+	image_pullCmd.Flags().Bool("disable-content-trust", false, "Skip image verification (deprecated)")
 	image_pullCmd.Flags().String("platform", "", "Set platform if server is multi-platform capable")
 	image_pullCmd.Flags().BoolP("quiet", "q", false, "Suppress verbose output")
+	image_pullCmd.Flag("disable-content-trust").Hidden = true
 	imageCmd.AddCommand(image_pullCmd)
 
 	carapace.Gen(image_pullCmd).PositionalCompletion(docker.ActionRepositoryTags())
