@@ -17,8 +17,10 @@ func init() {
 	carapace.Gen(stack_deployCmd).Standalone()
 
 	stack_deployCmd.Flags().StringSliceP("compose-file", "c", nil, "Path to a Compose file, or \"-\" to read from stdin")
+	stack_deployCmd.Flags().BoolP("detach", "d", false, "Exit immediately instead of waiting for the stack services to converge")
 	stack_deployCmd.Flags().Bool("prune", false, "Prune services that are no longer referenced")
-	stack_deployCmd.Flags().String("resolve-image", "always", "Query the registry to resolve image digest and supported platforms (\"always\", \"changed\", \"never\")")
+	stack_deployCmd.Flags().BoolP("quiet", "q", false, "Suppress progress output")
+	stack_deployCmd.Flags().String("resolve-image", "", "Query the registry to resolve image digest and supported platforms (\"always\", \"changed\", \"never\")")
 	stack_deployCmd.Flags().Bool("with-registry-auth", false, "Send registry authentication details to Swarm agents")
 	stackCmd.AddCommand(stack_deployCmd)
 
