@@ -16,7 +16,7 @@ func init() {
 	carapace.Gen(config_getCmd).Standalone()
 
 	config_getCmd.Flags().BoolP("global", "g", false, "Read from global config file (~/.config/glab-cli/config.yml). (default checks 'Environment variables → Local → Global')")
-	config_getCmd.Flags().StringP("host", "h", "", "Get per-host setting.")
+	config_getCmd.Flags().String("host", "", "Get per-host setting.")
 	configCmd.AddCommand(config_getCmd)
 
 	carapace.Gen(config_getCmd).FlagCompletion(carapace.ActionMap{
