@@ -15,10 +15,17 @@ func init() {
 	carapace.Gen(fmtCmd).Standalone()
 	fmtCmd.Flags().SetInterspersed(false)
 
+	fmtCmd.Flags().StringS("C", "C", "", "Change to dir before running the command")
 	fmtCmd.Flags().BoolS("mod", "mod", false, "set module download mode")
 	fmtCmd.Flags().BoolS("n", "n", false, "print commands that would be executed")
 	fmtCmd.Flags().BoolS("x", "x", false, "print commands as they are executed")
 	rootCmd.AddCommand(fmtCmd)
 
-	carapace.Gen(fmtCmd).PositionalAnyCompletion(carapace.ActionFiles())
+	carapace.Gen(fmtCmd).FlagCompletion(carapace.ActionMap{
+		"C": carapace.ActionDirectories(),
+	})
+
+	carapace.Gen(fmtCmd).PositionalAnyCompletion(
+		carapace.ActionFiles(),
+	)
 }
