@@ -18,7 +18,7 @@ func init() {
 	absorbCmd.Flags().StringP("from", "f", "@", "Source revision to absorb from")
 	absorbCmd.Flags().BoolP("help", "h", false, "Print help (see more with '--help')")
 	absorbCmd.Flags().StringSliceP("into", "t", []string{"mutable()"}, "Destination revisions to absorb into")
-	absorbCmd.Flags().StringSlice("to", []string{"mutable()"}, "Alias for --into")
+	absorbCmd.Flags().StringSlice("to", []string{"mutable()"}, "Destination revisions to absorb into")
 	rootCmd.AddCommand(absorbCmd)
 
 	absorbCmd.MarkFlagsMutuallyExclusive("into", "to")
