@@ -6,10 +6,9 @@ import (
 )
 
 var bookmarkCmd = &cobra.Command{
-	Use:     "bookmark",
-	Short:   "Manage bookmarks",
-	Aliases: []string{"branch", "b"},
-	Run:     func(cmd *cobra.Command, args []string) {},
+	Use:   "bookmark",
+	Short: "Manage bookmarks [default alias: b]",
+	Run:   func(cmd *cobra.Command, args []string) {},
 }
 
 func init() {
