@@ -7,12 +7,13 @@ import (
 
 var tagCmd = &cobra.Command{
 	Use:   "tag [OPTIONS] <COMMAND>",
-	Short: "Manage Tags",
+	Short: "Manage tags",
 	Run:   func(cmd *cobra.Command, args []string) {},
 }
 
 func init() {
 	carapace.Gen(tagCmd).Standalone()
 
+	tagCmd.Flags().BoolP("help", "h", false, "Print help (see more with '--help')")
 	rootCmd.AddCommand(tagCmd)
 }
