@@ -15,9 +15,9 @@ func init() {
 	carapace.Gen(buildCmd).Standalone()
 
 	buildCmd.Flags().StringP("dest-dir", "d", "", "Output directory for the book")
-	buildCmd.Flags().BoolP("help", "h", false, "Prints help information")
+	buildCmd.Flags().BoolP("help", "h", false, "Print help")
 	buildCmd.Flags().BoolP("open", "o", false, "Opens the compiled book in a web browser")
-	buildCmd.Flags().BoolP("version", "V", false, "Prints version information")
+	buildCmd.Flags().BoolP("version", "V", false, "Print version")
 	rootCmd.AddCommand(buildCmd)
 
 	carapace.Gen(buildCmd).FlagCompletion(carapace.ActionMap{
