@@ -15,9 +15,10 @@ var rootCmd = &cobra.Command{
 func Execute() error {
 	return rootCmd.Execute()
 }
+
 func init() {
 	carapace.Gen(rootCmd).Standalone()
 
-	rootCmd.Flags().BoolP("help", "h", false, "Prints help information")
-	rootCmd.Flags().BoolP("version", "V", false, "Prints version information")
+	rootCmd.Flags().BoolP("help", "h", false, "Print help")
+	rootCmd.Flags().BoolP("version", "V", false, "Print version")
 }
