@@ -6,7 +6,7 @@ import (
 )
 
 var configCmd = &cobra.Command{
-	Use:     "config",
+	Use:     "config SUBCOMMAND [flags]",
 	Short:   "Modify persistent configuration values",
 	GroupID: "configuration",
 	Run:     func(cmd *cobra.Command, args []string) {},
@@ -14,5 +14,6 @@ var configCmd = &cobra.Command{
 
 func init() {
 	carapace.Gen(configCmd).Standalone()
+
 	rootCmd.AddCommand(configCmd)
 }
