@@ -15,7 +15,8 @@ var sshCmd = &cobra.Command{
 
 func init() {
 	carapace.Gen(sshCmd).Standalone()
-	sshCmd.Flags().Bool("native-ssh", true, "Use native Golang SSH client (default true). Set to 'false' to use the command line 'ssh' command when accessing the docker machine. Useful for the machine drivers when they will not start with 'Waiting for SSH'.")
+
+	sshCmd.Flags().Bool("native-ssh", false, "Use native Golang SSH client (default true). Set to 'false' to use the command line 'ssh' command when accessing the docker machine. Useful for the machine drivers when they will not start with 'Waiting for SSH'.")
 	sshCmd.Flags().StringP("node", "n", "", "The node to ssh into. Defaults to the primary control plane.")
 	rootCmd.AddCommand(sshCmd)
 
