@@ -2,7 +2,6 @@ package cmd
 
 import (
 	"github.com/carapace-sh/carapace"
-	"github.com/carapace-sh/carapace-bin/completers/common/openssl_completer/cmd/action"
 	"github.com/carapace-sh/carapace-bin/completers/common/openssl_completer/cmd/common"
 	"github.com/spf13/cobra"
 )
@@ -17,7 +16,6 @@ var gendsaCmd = &cobra.Command{
 func init() {
 	carapace.Gen(gendsaCmd).Standalone()
 
-	gendsaCmd.Flags().StringS("engine", "engine", "", "Use engine, possibly a hardware device")
 	gendsaCmd.Flags().StringS("out", "out", "", "Output the key to the specified file")
 	gendsaCmd.Flags().StringS("passout", "passout", "", "Output file pass phrase source")
 	gendsaCmd.Flags().BoolS("quiet", "quiet", false, "Terse output")
@@ -27,8 +25,7 @@ func init() {
 	rootCmd.AddCommand(gendsaCmd)
 
 	carapace.Gen(gendsaCmd).FlagCompletion(carapace.ActionMap{
-		"engine": action.ActionEngines(),
-		"out":    carapace.ActionFiles(),
+		"out": carapace.ActionFiles(),
 	})
 
 	carapace.Gen(gendsaCmd).PositionalCompletion(
