@@ -2,7 +2,6 @@ package cmd
 
 import (
 	"github.com/carapace-sh/carapace"
-	"github.com/carapace-sh/carapace-bin/completers/common/openssl_completer/cmd/action"
 	"github.com/carapace-sh/carapace-bin/completers/common/openssl_completer/cmd/common"
 	"github.com/spf13/cobra"
 )
@@ -19,7 +18,6 @@ func init() {
 
 	genrsaCmd.Flags().BoolS("3", "3", false, "(deprecated) Use 3 for the E value")
 	genrsaCmd.Flags().BoolS("F4", "F4", false, "Use the Fermat number F4 (0x10001) for the E value")
-	genrsaCmd.Flags().StringS("engine", "engine", "", "Use engine, possibly a hardware device")
 	genrsaCmd.Flags().BoolS("f4", "f4", false, "Use the Fermat number F4 (0x10001) for the E value")
 	genrsaCmd.Flags().StringS("out", "out", "", "Output the key to specified file")
 	genrsaCmd.Flags().StringS("passout", "passout", "", "Output file pass phrase source")
@@ -32,7 +30,6 @@ func init() {
 	rootCmd.AddCommand(genrsaCmd)
 
 	carapace.Gen(genrsaCmd).FlagCompletion(carapace.ActionMap{
-		"engine": action.ActionEngines(),
-		"out":    carapace.ActionFiles(),
+		"out": carapace.ActionFiles(),
 	})
 }
