@@ -2,7 +2,6 @@ package cmd
 
 import (
 	"github.com/carapace-sh/carapace"
-	"github.com/carapace-sh/carapace-bin/completers/common/openssl_completer/cmd/action"
 	"github.com/carapace-sh/carapace-bin/completers/common/openssl_completer/cmd/common"
 	"github.com/spf13/cobra"
 )
@@ -18,7 +17,6 @@ func init() {
 	carapace.Gen(pkeyparamCmd).Standalone()
 
 	pkeyparamCmd.Flags().BoolS("check", "check", false, "Check key param consistency")
-	pkeyparamCmd.Flags().StringS("engine", "engine", "", "Use engine, possibly a hardware device")
 	pkeyparamCmd.Flags().StringS("in", "in", "", "Input file")
 	pkeyparamCmd.Flags().BoolS("noout", "noout", false, "Don't output encoded parameters")
 	pkeyparamCmd.Flags().StringS("out", "out", "", "Output file")
@@ -27,8 +25,7 @@ func init() {
 	rootCmd.AddCommand(pkeyparamCmd)
 
 	carapace.Gen(pkeyparamCmd).FlagCompletion(carapace.ActionMap{
-		"engine": action.ActionEngines(),
-		"in":     carapace.ActionFiles(),
-		"out":    carapace.ActionFiles(),
+		"in":  carapace.ActionFiles(),
+		"out": carapace.ActionFiles(),
 	})
 }
