@@ -2,7 +2,6 @@ package cmd
 
 import (
 	"github.com/carapace-sh/carapace"
-	"github.com/carapace-sh/carapace-bin/completers/common/openssl_completer/cmd/action"
 	"github.com/carapace-sh/carapace-bin/completers/common/openssl_completer/cmd/common"
 	"github.com/spf13/cobra"
 )
@@ -18,7 +17,6 @@ func init() {
 	carapace.Gen(randCmd).Standalone()
 
 	randCmd.Flags().BoolS("base64", "base64", false, "Base64 encode output")
-	randCmd.Flags().StringS("engine", "engine", "", "Use engine, possibly a hardware device")
 	randCmd.Flags().BoolS("hex", "hex", false, "Hex encode output")
 	randCmd.Flags().StringS("out", "out", "", "Output file")
 	common.AddProviderFlags(randCmd)
@@ -26,7 +24,6 @@ func init() {
 	rootCmd.AddCommand(randCmd)
 
 	carapace.Gen(randCmd).FlagCompletion(carapace.ActionMap{
-		"engine": action.ActionEngines(),
-		"out":    carapace.ActionFiles(),
+		"out": carapace.ActionFiles(),
 	})
 }
