@@ -14,7 +14,7 @@ var completionsCmd = &cobra.Command{
 func init() {
 	carapace.Gen(completionsCmd).Standalone()
 
-	completionsCmd.Flags().BoolP("help", "h", false, "Prints help information")
+	completionsCmd.Flags().BoolP("help", "h", false, "Print help")
 	rootCmd.AddCommand(completionsCmd)
 
 	carapace.Gen(completionsCmd).PositionalCompletion(
