@@ -7,17 +7,18 @@ import (
 )
 
 var component_removeCmd = &cobra.Command{
-	Use:   "remove",
-	Short: "Remove a component from a Rust toolchain",
-	Run:   func(cmd *cobra.Command, args []string) {},
+	Use:     "remove",
+	Short:   "Remove a component from a Rust toolchain",
+	Aliases: []string{"uninstall", "rm", "delete", "del"},
+	Run:     func(cmd *cobra.Command, args []string) {},
 }
 
 func init() {
 	carapace.Gen(component_removeCmd).Standalone()
 
-	component_removeCmd.Flags().BoolP("help", "h", false, "Prints help information")
+	component_removeCmd.Flags().BoolP("help", "h", false, "Print help")
 	component_removeCmd.Flags().String("target", "", "")
-	component_removeCmd.Flags().String("toolchain", "", "Toolchain name, such as 'stable', 'nightly', or '1.8.0'. For more information see")
+	component_removeCmd.Flags().String("toolchain", "", "Toolchain name, such as 'stable', 'nightly', or '1.8.0'. For more information see `rustup help toolchain`")
 	componentCmd.AddCommand(component_removeCmd)
 
 	carapace.Gen(component_removeCmd).FlagCompletion(carapace.ActionMap{
