@@ -7,13 +7,13 @@ import (
 
 var self_upgradeDataCmd = &cobra.Command{
 	Use:   "upgrade-data",
-	Short: "Upgrade the internal data format.",
+	Short: "Upgrade the internal data format",
 	Run:   func(cmd *cobra.Command, args []string) {},
 }
 
 func init() {
 	carapace.Gen(self_upgradeDataCmd).Standalone()
 
-	self_upgradeDataCmd.Flags().BoolP("help", "h", false, "Prints help information")
+	self_upgradeDataCmd.Flags().BoolP("help", "h", false, "Print help")
 	selfCmd.AddCommand(self_upgradeDataCmd)
 }
