@@ -7,13 +7,13 @@ import (
 
 var toolchainCmd = &cobra.Command{
 	Use:   "toolchain",
-	Short: "Modify or query the installed toolchains",
+	Short: "Install, uninstall, or list toolchains",
 	Run:   func(cmd *cobra.Command, args []string) {},
 }
 
 func init() {
 	carapace.Gen(toolchainCmd).Standalone()
 
-	toolchainCmd.Flags().BoolP("help", "h", false, "Prints help information")
+	toolchainCmd.Flags().BoolP("help", "h", false, "Print help")
 	rootCmd.AddCommand(toolchainCmd)
 }
