@@ -14,7 +14,8 @@ var toolchain_listCmd = &cobra.Command{
 func init() {
 	carapace.Gen(toolchain_listCmd).Standalone()
 
-	toolchain_listCmd.Flags().BoolP("help", "h", false, "Prints help information")
+	toolchain_listCmd.Flags().BoolP("help", "h", false, "Print help")
+	toolchain_listCmd.Flags().BoolP("quiet", "q", false, "Force the output to be a single column")
 	toolchain_listCmd.Flags().BoolP("verbose", "v", false, "Enable verbose output with toolchain information")
 	toolchainCmd.AddCommand(toolchain_listCmd)
 }
