@@ -37,7 +37,7 @@ func ActionLabels(opts RepoOpts) carapace.Action {
 			}
 			return carapace.ActionStyledValuesDescribed(vals...)
 		})
-	}).Cache(24*time.Hour, opts.cacheKey())
+	}).Tag("labels").Cache(24*time.Hour, opts.cacheKey())
 }
 
 // ActionLabelFields completes label fields
