@@ -33,6 +33,7 @@ func ActionLanguages() carapace.Action {
 		"Adblock Filter List", "data",
 		"Adobe Font Metrics", "data",
 		"Agda", "programming",
+		"Aiken", "programming",
 		"Alloy", "programming",
 		"Alpine Abuild", "programming",
 		"Altium Designer", "data",
@@ -80,11 +81,14 @@ func ActionLanguages() carapace.Action {
 		"BrighterScript", "programming",
 		"Brightscript", "programming",
 		"Browserslist", "data",
+		"Bru", "markup",
+		"BuildStream", "data",
 		"C", "programming",
 		"C#", "programming",
 		"C++", "programming",
 		"C-ObjDump", "data",
 		"C2hs Haskell", "programming",
+		"C3", "programming",
 		"CAP CDS", "programming",
 		"CIL", "data",
 		"CLIPS", "programming",
@@ -121,6 +125,7 @@ func ActionLanguages() carapace.Action {
 		"Clojure", "programming",
 		"Closure Templates", "markup",
 		"Cloud Firestore Security Rules", "data",
+		"Clue", "programming",
 		"CoNLL-U", "data",
 		"CodeQL", "programming",
 		"CoffeeScript", "programming",
@@ -129,8 +134,8 @@ func ActionLanguages() carapace.Action {
 		"Common Lisp", "programming",
 		"Common Workflow Language", "programming",
 		"Component Pascal", "programming",
+		"Cooklang", "markup",
 		"Cool", "programming",
-		"Coq", "programming",
 		"Cpp-ObjDump", "data",
 		"Creole", "prose",
 		"Crystal", "programming",
@@ -154,6 +159,7 @@ func ActionLanguages() carapace.Action {
 		"Dafny", "programming",
 		"Darcs Patch", "data",
 		"Dart", "programming",
+		"Daslang", "programming",
 		"DataWeave", "programming",
 		"Debian Package Control File", "data",
 		"DenizenScript", "programming",
@@ -202,6 +208,7 @@ func ActionLanguages() carapace.Action {
 		"Fennel", "programming",
 		"Filebench WML", "programming",
 		"Filterscript", "programming",
+		"Flix", "programming",
 		"Fluent", "programming",
 		"Formatted", "data",
 		"Forth", "programming",
@@ -218,6 +225,7 @@ func ActionLanguages() carapace.Action {
 		"GCC Machine Description", "programming",
 		"GDB", "programming",
 		"GDScript", "programming",
+		"GDShader", "programming",
 		"GEDCOM", "data",
 		"GLSL", "programming",
 		"GN", "data",
@@ -261,6 +269,7 @@ func ActionLanguages() carapace.Action {
 		"Groovy Server Pages", "programming",
 		"HAProxy", "data",
 		"HCL", "programming",
+		"HIP", "programming",
 		"HLSL", "programming",
 		"HOCON", "data",
 		"HTML", "markup",
@@ -338,6 +347,8 @@ func ActionLanguages() carapace.Action {
 		"KiCad Schematic", "data",
 		"Kickstart", "data",
 		"Kit", "markup",
+		"KoLMafia ASH", "programming",
+		"Koka", "programming",
 		"Kotlin", "programming",
 		"Kusto", "data",
 		"LFE", "programming",
@@ -351,6 +362,7 @@ func ActionLanguages() carapace.Action {
 		"Latte", "markup",
 		"Lean", "programming",
 		"Lean 4", "programming",
+		"Leo", "programming",
 		"Less", "markup",
 		"Lex", "programming",
 		"LigoLANG", "programming",
@@ -372,6 +384,7 @@ func ActionLanguages() carapace.Action {
 		"Lua", "programming",
 		"Luau", "programming",
 		"M", "programming",
+		"M3U", "data",
 		"M4", "programming",
 		"M4Sugar", "programming",
 		"MATLAB", "programming",
@@ -436,6 +449,7 @@ func ActionLanguages() carapace.Action {
 		"NewLisp", "programming",
 		"Nextflow", "programming",
 		"Nginx", "data",
+		"Nickel", "programming",
 		"Nim", "programming",
 		"Ninja", "data",
 		"Nit", "programming",
@@ -539,6 +553,7 @@ func ActionLanguages() carapace.Action {
 		"QMake", "programming",
 		"Qt Script", "programming",
 		"Quake", "programming",
+		"QuakeC", "programming",
 		"QuickBASIC", "programming",
 		"R", "programming",
 		"RAML", "markup",
@@ -548,6 +563,7 @@ func ActionLanguages() carapace.Action {
 		"REXX", "programming",
 		"RMarkdown", "prose",
 		"RON", "data",
+		"ROS Interface", "data",
 		"RPC", "programming",
 		"RPGLE", "programming",
 		"RPM Spec", "data",
@@ -575,6 +591,7 @@ func ActionLanguages() carapace.Action {
 		"Riot", "markup",
 		"RobotFramework", "programming",
 		"Roc", "programming",
+		"Rocq Prover", "programming",
 		"Roff", "markup",
 		"Roff Manpage", "markup",
 		"Rouge", "programming",
@@ -597,6 +614,7 @@ func ActionLanguages() carapace.Action {
 		"SVG", "data",
 		"SWIG", "programming",
 		"Sage", "programming",
+		"Sail", "programming",
 		"SaltStack", "programming",
 		"Sass", "markup",
 		"Scala", "programming",
@@ -668,6 +686,7 @@ func ActionLanguages() carapace.Action {
 		"Textile", "prose",
 		"Thrift", "programming",
 		"Toit", "programming",
+		"Tor Config", "data",
 		"Tree-sitter Query", "programming",
 		"Turing", "programming",
 		"Turtle", "data",
@@ -681,6 +700,7 @@ func ActionLanguages() carapace.Action {
 		"Unix Assembly", "programming",
 		"Uno", "programming",
 		"UnrealScript", "programming",
+		"Untyped Plutus Core", "programming",
 		"UrWeb", "programming",
 		"V", "programming",
 		"VBA", "programming",
@@ -690,6 +710,7 @@ func ActionLanguages() carapace.Action {
 		"Vala", "programming",
 		"Valve Data Format", "data",
 		"Velocity Template Language", "markup",
+		"Vento", "markup",
 		"Verilog", "programming",
 		"Vim Help File", "prose",
 		"Vim Script", "programming",
@@ -747,6 +768,7 @@ func ActionLanguages() carapace.Action {
 		"Zephir", "programming",
 		"Zig", "programming",
 		"Zimpl", "programming",
+		"Zmodel", "data",
 		"cURL Config", "data",
 		"crontab", "data",
 		"desktop", "data",
