@@ -1,6 +1,10 @@
 package ghostty
 
-import "github.com/carapace-sh/carapace"
+import (
+	"strings"
+
+	"github.com/carapace-sh/carapace"
+)
 
 // ActionFontSyntheticStyles completes font synthetic styles
 //
@@ -16,7 +20,7 @@ func ActionFontSyntheticStyles() carapace.Action {
 		"no-bold-italic", "disable for bold-italic",
 		"no-italic", "disable for italic",
 		"true", "completely enable",
-	)
+	).Tag("font synthetic styles")
 }
 
 // ActionFreetypeLoadFlags completes freetype load flags
@@ -33,5 +37,23 @@ func ActionFreetypeLoadFlags() carapace.Action {
 		"no-force-autohint", "Do not se the freetype auto-hinter",
 		"no-monochrome", "Do not use 1-bit monochrome rendering",
 		"no-autohint", "Do not use the freetype auto-hinter",
-	)
+	).Tag("freetype load flags")
+}
+
+// ActionFontFamilies completes font families
+//
+//	FreeMono
+//	FreeSans
+func ActionFontFamilies() carapace.Action {
+	return carapace.ActionExecCommand("ghostty", "+list-fonts")(func(output []byte) carapace.Action {
+		lines := strings.Split(string(output), "\n")
+
+		vals := make([]string, 0)
+		for _, line := range lines {
+			if line != "" && !strings.HasPrefix(line, " ") {
+				vals = append(vals, line)
+			}
+		}
+		return carapace.ActionValues(vals...)
+	}).Tag("font families")
 }
